@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2020 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -1333,3 +1333,30 @@ void Database_Config_User::setOrderChangesByAuthor (bool value)
   setBValue (order_changes_by_author_key (), value);
 }
 
+
+const char * automatic_note_assignment_key ()
+{
+  return "automatic-note-assignment";
+}
+vector <string> Database_Config_User::getAutomaticNoteAssignment ()
+{
+  return getList (automatic_note_assignment_key ());
+}
+void Database_Config_User::setAutomaticNoteAssignment (vector <string> values)
+{
+  setList (automatic_note_assignment_key (), values);
+}
+
+
+const char * receive_focused_reference_from_paratext_key ()
+{
+  return "receive-focused-reference-from-paratext";
+}
+bool Database_Config_User::getReceiveFocusedReferenceFromParatext ()
+{
+  return getBValue (receive_focused_reference_from_paratext_key (), true);
+}
+void Database_Config_User::setReceiveFocusedReferenceFromParatext (bool value)
+{
+  setBValue (receive_focused_reference_from_paratext_key (), value);
+}
