@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2019 Teus Benschop.
+Copyright (©) 2003-2020 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -28,3 +28,17 @@ function debugLog (message)
   });
 }
 
+
+function showAlertWithTimeout ()
+{
+  notifyItSuccess ("The keyboard is blocked for a short while")
+  $("#textinput").prop ("readonly", true);
+  setTimeout (enableTextInput, 1000);
+}
+
+
+function enableTextInput ()
+{
+  $("#textinput").prop ("readonly", false);
+}
+
