@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2020 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -71,7 +71,8 @@ string edit_save (void * webserver_request)
   int chapter = convert_to_int (request->post["chapter"]);
   string html = request->post["html"];
   string checksum = request->post["checksum"];
-  
+  string unique_id = request->post ["id"];
+
   if (Checksum_Logic::get (html) != checksum) {
     request->response_code = 409;
     return translate("Checksum error");
@@ -97,13 +98,12 @@ string edit_save (void * webserver_request)
   string stylesheet = Database_Config_Bible::getEditorStylesheet (bible);
   
   Editor_Html2Usfm editor_export;
-  editor_export.quill ();
   editor_export.load (html);
   editor_export.stylesheet (stylesheet);
   editor_export.run ();
   string user_usfm = editor_export.get ();
 
-  string ancestor_usfm = getLoadedUsfm (webserver_request, bible, book, chapter, "editql");
+  string ancestor_usfm = getLoadedUsfm (webserver_request, bible, book, chapter, unique_id);
   
   vector <BookChapterData> book_chapter_text = usfm_import (user_usfm, stylesheet);
   if (book_chapter_text.size () != 1) {
@@ -154,7 +154,7 @@ string edit_save (void * webserver_request)
   if (ancestor_usfm != server_usfm) {
     bible_logic_recent_save_email (bible, book, chapter, 0, username, ancestor_usfm, server_usfm);
   }
-  
+
   // Safely store the chapter.
   string explanation;
   string message = usfm_safely_store_chapter (request, bible, book, chapter, user_usfm, explanation);
@@ -176,7 +176,7 @@ string edit_save (void * webserver_request)
 #endif
 
   // Store a copy of the USFM loaded in the editor for later reference.
-  storeLoadedUsfm (webserver_request, bible, book, chapter, "editql");
+  storeLoadedUsfm (webserver_request, bible, book, chapter, unique_id);
   
   // Convert the stored USFM to html.
   // This converted html should be the same as the saved html.
