@@ -34,7 +34,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <database/userresources.h>
 #include <developer/index.h>
 #include <edit/index.h>
-#include <editone/index.h>
+#include <editone2/index.h>
+#include <redirect/index.h>
 #include <editusfm/index.h>
 #include <email/index.h>
 #include <filter/string.h>
@@ -264,8 +265,8 @@ string menu_logic_basic_categories (void * webserver_request)
 
   vector <string> html;
   
-  if (editone_index_acl (webserver_request)) {
-    html.push_back (menu_logic_create_item (editone_index_url (), translate ("Translation"), true));
+  if (editone2_index_acl (webserver_request)) {
+    html.push_back (menu_logic_create_item (editone2_index_url (), translate ("Translation"), true));
   }
   
   if (changes_changes_acl (webserver_request)) {
@@ -354,9 +355,9 @@ string menu_logic_translate_category (void * webserver_request, string * tooltip
   }
 
   // Visual verse editor.
-  if (editone_index_acl (webserver_request)) {
+  if (editone2_index_acl (webserver_request)) {
     string label = menu_logic_editor_menu_text (true, false);
-    html.push_back (menu_logic_create_item (editone_index_url (), label, true));
+    html.push_back (menu_logic_create_item (editone2_index_url (), label, true));
     labels.push_back (label);
   }
 
@@ -1202,7 +1203,7 @@ void menu_logic_tabbed_mode_save_json (void * webserver_request)
       jsonxx::Array json_array;
       // Adding tabs in the order an average translator uses them most of the time:
       // Add the Bible editor tab.
-      json_array << menu_logic_tabbed_mode_add_tab (editone_index_url (), menu_logic_translate_text ());
+      json_array << menu_logic_tabbed_mode_add_tab (editone2_index_url (), menu_logic_translate_text ());
       // Add the resources tab.
       json_array << menu_logic_tabbed_mode_add_tab (resource_index_url (), menu_logic_resources_text ());
       // Add the consultation notes tab.
@@ -1220,3 +1221,15 @@ void menu_logic_tabbed_mode_save_json (void * webserver_request)
 
   Database_Config_General::setMenuInTabbedViewJSON (json);
 }
+
+
+string menu_logic_verse_separator (string separator)
+{
+  if (separator == ".") {
+    return translate ("dot") + " ( . )";
+  }
+  if (separator == ":") {
+    return translate ("colon") + " ( : )";
+  }
+  return " ( " + separator + " ) ";
+}
